==> cms-db_v0.6.tar.gz: admin/tabs.js <==
/*  cms-db  Copyright (C) 2007-2009 Jan Hoffmann
    This program comes with ABSOLUTELY NO WARRANTY; for details see /admin/version.php.
    This is free software, and you are welcome to redistribute it under certain conditions; see /admin/version.php for details.  */


var tabs = new Array();
var activetab = "";
function IframeOnLoad(tab) {
	var iframe = document.getElementById('iframe_'+tab);
	if (iframe.contentDocument) {
		var iframecontent = iframe.contentDocument;
	} else if (iframe.contentWindow) {
		try {
			var iframecontent = iframe.contentWindow.document;
		} catch (e) {
			document.getElementById('title_'+tab).firstChild.nodeValue = 'undefined';
			var attrtitle = document.createAttribute("title");
			attrtitle.nodeValue = "Error: The title could not be set.";
			document.getElementById('title_'+tab).setAttributeNode(attrtitle);
		}
	}
	try {
		var title = iframecontent.title;
		if (title.length > 15) {
			title = title.slice(0, 15)+'...';
		}
		document.getElementById('title_'+tab).firstChild.nodeValue = title;
		var attrtitle = document.createAttribute("title");
		attrtitle.nodeValue = iframecontent.title;
		document.getElementById('title_'+tab).setAttributeNode(attrtitle);
	} catch (e) {
		document.getElementById('title_'+tab).firstChild.nodeValue = 'undefined';
		var attrtitle = document.createAttribute("title");
		attrtitle.nodeValue = "Error: The title could not be set.";
		document.getElementById('title_'+tab).setAttributeNode(attrtitle);
	}
	resizeIframes();
}
function IframeOnUnload(tab) {
	document.getElementById('title_'+tab).firstChild.nodeValue = 'loading...';
}
function newTab(source, id) {
	var id = !id?"auto":id;
	if (id == "auto") {
		var min = 0;
		var max = 100000;
		var random = Math.round(Math.random() * (max - min)) + min;
	} else {
		var random = id;
	}
	/* Start Tab */
		var span = document.createElement("a");
		/* Start linkes Ecken-Element */
			var leftspan = document.createElement("span");
			var leftclass = document.createAttribute("class");
			leftclass.nodeValue = 'tableft';
			leftspan.setAttributeNode(leftclass);
			span.appendChild(leftspan);
		/* Ende linkes Ecken-Element*/
		/* Start Tab-Name */
			var textspan = document.createElement("span");
			var text = document.createTextNode('untitled');
			textspan.appendChild(text);
			var textid = document.createAttribute("id");
			textid.nodeValue = 'title_'+random;
			textspan.setAttributeNode(textid);
			span.appendChild(textspan);
		/* Ende Tab-Name */
		/* Start Schliessen-Button */
			var close = document.createElement("img");
			var closeimg = document.createAttribute("src");
			closeimg.nodeValue = "close.png";
			close.setAttributeNode(closeimg);
			if (navigator.appName.indexOf("Explorer") == -1) {
				var closestyle = document.createAttribute("style");
				closestyle.nodeValue = "border:none;margin-top:2px";
				close.setAttributeNode(closestyle);
			} else {
				close.style.setAttribute("border", "none", false);
				close.style.setAttribute("marginTop", "2px", false);
			}
			var closealt = document.createAttribute("alt");
			closealt.nodeValue = unescape("Schlie%DFen");
			close.setAttributeNode(closealt);
			var closetitle = document.createAttribute("title");
			closetitle.nodeValue = unescape("Schlie%DFen");
			close.setAttributeNode(closetitle);
			if (navigator.appName.indexOf("Explorer") == -1) {
				var onclose = document.createAttribute("onclick");
				onclose.nodeValue = "closeTab('"+random+"')";
				close.setAttributeNode(onclose);
			} else {
				close.onclick = function(){closeTab(random);};
			}
			span.appendChild(close);
		/* Ende Schliessen-Button */
		/* Start rechtes Ecken-Element */
			var rightspan = document.createElement("span");
			var rightclass = document.createAttribute("class");
			rightclass.nodeValue = 'tabright';
			rightspan.setAttributeNode(rightclass);
			span.appendChild(rightspan);
		/* Ende rechtes Ecken-Element*/
		var style = document.createAttribute("class");
		style.nodeValue = "tab";
		span.setAttributeNode(style);
		var id = document.createAttribute("id");
		id.nodeValue = "tab_"+random;
		span.setAttributeNode(id);
		var onclick = document.createAttribute("href");
		onclick.nodeValue = "javascript:openTab('"+random+"')";
		span.setAttributeNode(onclick);
		document.getElementById('tabs').appendChild(span);
		var space = document.createTextNode(' ');
		document.getElementById('tabs').appendChild(space);
	/* Ende Tab */
	/* Start Iframe */
		var iframe = document.createElement("iframe");
		var framesrc = document.createAttribute("src");
		framesrc.nodeValue = source;
		iframe.setAttributeNode(framesrc);
		var frameid = document.createAttribute("id");
		frameid.nodeValue = "iframe_"+random;
		iframe.setAttributeNode(frameid);
		var framename = document.createAttribute("name");
		framename.nodeValue = "iframe_"+random;
		iframe.setAttributeNode(framename);
		if (navigator.appName.indexOf("Explorer") == -1) {
			var onload = document.createAttribute("onload");
			onload.nodeValue = "IframeOnLoad('"+random+"')";
			iframe.setAttributeNode(onload);
		} else {
			//iframe.onload = function(){IframeOnLoad(random);};
			window.setInterval("IframeOnLoad('"+random+"')", 1000);
			window.setTimeout("IframeOnLoad('"+random+"')", 100);
		}
		if (navigator.appName.indexOf("Explorer") == -1) {
			var onunload = document.createAttribute("onunload");
			onunload.nodeValue = "IframeOnUnload('"+random+"')";
			iframe.setAttributeNode(onunload);
		} else {
			//iframe.onunload = function(){IframeOnUnload(random);};
		}
		var height_tabs = document.getElementById("tabs").offsetHeight;
		if (navigator.appName.indexOf("Explorer") != -1) {
			var cwidth = document.documentElement.clientWidth;
			var cheight = document.documentElement.clientHeight;
			var ifrmwidth = cwidth;
			var ifrmheight = cheight - 24 - height_tabs;
		} else {
			var iwidth = window.innerWidth;
			var iheight = window.innerHeight;
			var ifrmwidth = iwidth;
			var ifrmheight = iheight - 24 - height_tabs;
		}
		var ifrmtop = 24 + height_tabs;
		if (navigator.appName.indexOf("Explorer") == -1) {
			var framestyle = document.createAttribute("style");
			framestyle.nodeValue = "left;0px;top:"+ifrmtop+"px;width:"+ifrmwidth+"px;height:"+ifrmheight+"px";
			iframe.setAttributeNode(framestyle);
		} else {
			iframe.style.setAttribute("left", "0px", false);
			iframe.style.setAttribute("top", ifrmtop+"px", false);
			iframe.style.setAttribute("width", ifrmwidth+"px", false);
			iframe.style.setAttribute("height", ifrmheight+"px", false);
		}
		document.getElementById('iframes').appendChild(iframe);
	/* Ende Iframe */
	tabs.push(random);
	if (window.location.hash.indexOf(random+";") == -1) {
		window.location.hash += random+";";
	}
	openTab(random);
}
function openInActiveTab(source) {
	if (activetab &&document.getElementById('iframe_'+activetab)) {
		var framesrc = document.createAttribute("src");
		framesrc.nodeValue = source;
		document.getElementById('iframe_'+activetab).setAttributeNode(framesrc);
	} else {
		newTab(source)
	}
}
function hideActiveTab() {
	if (activetab &&document.getElementById('tab_'+activetab)) {
		classname = document.createAttribute("class");
		classname.nodeValue = "tab";
		document.getElementById('tab_'+activetab).setAttributeNode(classname);
		// Don't do this because firefox wouldn't restore this tab after a crash
		document.getElementById('iframe_'+activetab).style.display = "none";
		//document.getElementById('iframe_'+activetab).style.left = "-10000px";
	}
}
function openTab(tab) {
	hideActiveTab();
	var classname = document.createAttribute("class");
	classname.nodeValue = "tab activetab";
	document.getElementById('tab_'+tab).setAttributeNode(classname);
	var iframe = document.getElementById('iframe_'+tab);
	iframe.style.display = "block"; // display tab hidden in newTab()
	//iframe.style.left = "0px"; // See comment in hideActiveTab
	iframe.style.border = "none";
	activetab = tab;
}
function closeTab(tab) {
	var tabtoclose = document.getElementById("tab_"+tab);
	document.getElementById("tabs").removeChild(tabtoclose);
	var iframetoclose = document.getElementById("iframe_"+tab);
	document.getElementById("iframes").removeChild(iframetoclose);
	var oldtablist = tabs;
	tabs = new Array();
	for (var i = 0; i < oldtablist.length; ++i) {
		if (oldtablist[i] != tab) {
			tabs.push(oldtablist[i]);
		}
	}
	window.location.hash = window.location.hash.replace(tab+";", "");
	resizeIframes();
}
function resizeIframes() {
	var height_tabs = document.getElementById("tabs").offsetHeight;
	if (navigator.appName.indexOf("Explorer") != -1) {
		var cwidth = document.documentElement.clientWidth;
		var cheight = document.documentElement.clientHeight;
		var ifrmwidth = cwidth;
		var ifrmheight = cheight - 24 - height_tabs;
	} else {
		var iwidth = window.innerWidth;
		var iheight = window.innerHeight;
		var ifrmwidth = iwidth;
		var ifrmheight = iheight - 24 - height_tabs;
	}
	var ifrmtop = 24 + height_tabs;
	var iframe;
	var framewidth;
	var frameheight;
	for (var i = 0; i < tabs.length; ++i) {
		iframe = document.getElementById('iframe_'+tabs[i]);
		iframe.style.width = ifrmwidth+"px";
		iframe.style.height = ifrmheight+"px";
		iframe.style.top = ifrmtop+"px";
	}
}
function restoreTabs() {
	var hash = window.location.hash.split(";");
	hash.shift();
	hash.pop();
	for (var i = 0; i < hash.length; ++i) {
		newTab("javascript:document.write(\""+hash[i]+"\");", hash[i]);
	}
}

==> cms-db_v0.6.1.tar.gz: admin/tabs.js <==
/*  cms-db  Copyright (C) 2007-2009 Jan Hoffmann
    This program comes with ABSOLUTELY NO WARRANTY; for details see /admin/version.php.
    This is free software, and you are welcome to redistribute it under certain conditions; see /admin/version.php for details.  */


var tabs = new Array();
var activetab = "";
function IframeOnLoad(tab) {
	var iframe = document.getElementById('iframe_'+tab);
	if (iframe.contentDocument) {
		var iframecontent = iframe.contentDocument;
	} else if (iframe.contentWindow) {
		try {
			var iframecontent = iframe.contentWindow.document;
		} catch (e) {
			document.getElementById('title_'+tab).firstChild.nodeValue = 'undefined\u00a0';
			var attrtitle = document.createAttribute("title");
			attrtitle.nodeValue = "Error: The title could not be set.";
			document.getElementById('title_'+tab).setAttributeNode(attrtitle);
		}
	}
	try {
		var title = iframecontent.title;
		if (title.length > 17) {
			title = title.slice(0, 15)+'...';
		}
		document.getElementById('title_'+tab).firstChild.nodeValue = title+'\u00a0';
		var attrtitle = document.createAttribute("title");
		attrtitle.nodeValue = iframecontent.title;
		document.getElementById('title_'+tab).setAttributeNode(attrtitle);
	} catch (e) {
		document.getElementById('title_'+tab).firstChild.nodeValue = 'undefined\u00a0';
		var attrtitle = document.createAttribute("title");
		attrtitle.nodeValue = "Error: The title could not be set.";
		document.getElementById('title_'+tab).setAttributeNode(attrtitle);
	}
	resizeIframes();
}
function IframeOnUnload(tab) {
	document.getElementById('title_'+tab).firstChild.nodeValue = 'loading...\u00a0';
}
function newTab(source, id) {
	var id = !id?"auto":id;
	if (id == "auto") {
		var min = 0;
		var max = 100000;
		var random = Math.round(Math.random() * (max - min)) + min;
	} else {
		var random = id;
	}
	/* Start Tab */
		var span = document.createElement("a");
		/* Start linkes Ecken-Element */
			var leftspan = document.createElement("span");
			var leftclass = document.createAttribute("class");
			leftclass.nodeValue = 'tableft';
			leftspan.setAttributeNode(leftclass);
			span.appendChild(leftspan);
		/* Ende linkes Ecken-Element*/
		/* Start Tab-Name */
			var textspan = document.createElement("span");
			var text = document.createTextNode('untitled\u00a0');
			textspan.appendChild(text);
			var textid = document.createAttribute("id");
			textid.nodeValue = 'title_'+random;
			textspan.setAttributeNode(textid);
			span.appendChild(textspan);
		/* Ende Tab-Name */
		/* Start Schliessen-Button */
			var close = document.createElement("img");
			var closeimg = document.createAttribute("src");
			closeimg.nodeValue = "close.png";
			close.setAttributeNode(closeimg);
			if (navigator.appName.indexOf("Explorer") == -1) {
				var closestyle = document.createAttribute("style");
				closestyle.nodeValue = "border:none;margin-top:2px";
				close.setAttributeNode(closestyle);
			} else {
				close.style.setAttribute("border", "none", false);
				close.style.setAttribute("marginTop", "2px", false);
			}
			var closealt = document.createAttribute("alt");
			closealt.nodeValue = unescape("Schlie%DFen");
			close.setAttributeNode(closealt);
			var closetitle = document.createAttribute("title");
			closetitle.nodeValue = unescape("Schlie%DFen");
			close.setAttributeNode(closetitle);
			if (navigator.appName.indexOf("Explorer") == -1) {
				var onclose = document.createAttribute("onclick");
				onclose.nodeValue = "closeTab('"+random+"')";
				close.setAttributeNode(onclose);
			} else {
				close.onclick = function(){closeTab(random);};
			}
			span.appendChild(close);
		/* Ende Schliessen-Button */
		/* Start rechtes Ecken-Element */
			var rightspan = document.createElement("span");
			var rightclass = document.createAttribute("class");
			rightclass.nodeValue = 'tabright';
			rightspan.setAttributeNode(rightclass);
			span.appendChild(rightspan);
		/* Ende rechtes Ecken-Element*/
		var style = document.createAttribute("class");
		style.nodeValue = "tab";
		span.setAttributeNode(style);
		var id = document.createAttribute("id");
		id.nodeValue = "tab_"+random;
		span.setAttributeNode(id);
		var onclick = document.createAttribute("href");
		onclick.nodeValue = "javascript:openTab('"+random+"')";
		span.setAttributeNode(onclick);
		document.getElementById('tabs').appendChild(span);
		var space = document.createTextNode(' ');
		document.getElementById('tabs').appendChild(space);
	/* Ende Tab */
	/* Start Iframe */
		var iframe = document.createElement("iframe");
		var framesrc = document.createAttribute("src");
		framesrc.nodeValue = source;
		iframe.setAttributeNode(framesrc);
		var frameid = document.createAttribute("id");
		frameid.nodeValue = "iframe_"+random;
		iframe.setAttributeNode(frameid);
		var framename = document.createAttribute("name");
		framename.nodeValue = "iframe_"+random;
		iframe.setAttributeNode(framename);
		if (navigator.appName.indexOf("Explorer") == -1) {
			var onload = document.createAttribute("onload");
			onload.nodeValue = "IframeOnLoad('"+random+"')";
			iframe.setAttributeNode(onload);
		} else {
			//iframe.onload = function(){IframeOnLoad(random);};
			window.setInterval("IframeOnLoad('"+random+"')", 1000);
			window.setTimeout("IframeOnLoad('"+random+"')", 100);
		}
		if (navigator.appName.indexOf("Explorer") == -1) {
			var onunload = document.createAttribute("onunload");
			onunload.nodeValue = "IframeOnUnload('"+random+"')";
			iframe.setAttributeNode(onunload);
		} else {
			//iframe.onunload = function(){IframeOnUnload(random);};
		}
		var height_tabs = document.getElementById("tabs").offsetHeight;
		if (navigator.appName.indexOf("Explorer") != -1) {
			var cwidth = document.documentElement.clientWidth;
			var cheight = document.documentElement.clientHeight;
			var ifrmwidth = cwidth;
			var ifrmheight = cheight - 24 - height_tabs;
		} else {
			var iwidth = window.innerWidth;
			var iheight = window.innerHeight;
			var ifrmwidth = iwidth;
			var ifrmheight = iheight - 24 - height_tabs;
		}
		var ifrmtop = 24 + height_tabs;
		if (navigator.appName.indexOf("Explorer") == -1) {
			var framestyle = document.createAttribute("style");
			framestyle.nodeValue = "left;0px;top:"+ifrmtop+"px;width:"+ifrmwidth+"px;height:"+ifrmheight+"px";
			iframe.setAttributeNode(framestyle);
		} else {
			iframe.style.setAttribute("left", "0px", false);
			iframe.style.setAttribute("top", ifrmtop+"px", false);
			iframe.style.setAttribute("width", ifrmwidth+"px", false);
			iframe.style.setAttribute("height", ifrmheight+"px", false);
		}
		document.getElementById('iframes').appendChild(iframe);
	/* Ende Iframe */
	tabs.push(random);
	if (window.location.hash.indexOf(random+";") == -1) {
		window.location.hash += random+";";
	}
	openTab(random);
}
function openInActiveTab(source) {
	if (activetab &&document.getElementById('iframe_'+activetab)) {
		var framesrc = document.createAttribute("src");
		framesrc.nodeValue = source;
		document.getElementById('iframe_'+activetab).setAttributeNode(framesrc);
	} else {
		newTab(source)
	}
}
function hideActiveTab() {
	if (activetab &&document.getElementById('tab_'+activetab)) {
		classname = document.createAttribute("class");
		classname.nodeValue = "tab";
		document.getElementById('tab_'+activetab).setAttributeNode(classname);
		// Don't do this because firefox wouldn't restore this tab after a crash
		document.getElementById('iframe_'+activetab).style.display = "none";
		//document.getElementById('iframe_'+activetab).style.left = "-10000px";
	}
}
function openTab(tab) {
	hideActiveTab();
	var classname = document.createAttribute("class");
	classname.nodeValue = "tab activetab";
	document.getElementById('tab_'+tab).setAttributeNode(classname);
	var iframe = document.getElementById('iframe_'+tab);
	iframe.style.display = "block"; // display tab hidden in newTab()
	//iframe.style.left = "0px"; // See comment in hideActiveTab
	iframe.style.border = "none";
	activetab = tab;
}
function closeTab(tab) {
	var tabtoclose = document.getElementById("tab_"+tab);
	document.getElementById("tabs").removeChild(tabtoclose);
	var iframetoclose = document.getElementById("iframe_"+tab);
	document.getElementById("iframes").removeChild(iframetoclose);
	var oldtablist = tabs;
	tabs = new Array();
	for (var i = 0; i < oldtablist.length; ++i) {
		if (oldtablist[i] != tab) {
			tabs.push(oldtablist[i]);
		}
	}
	window.location.hash = window.location.hash.replace(tab+";", "");
	resizeIframes();
}
function resizeIframes() {
	var height_tabs = document.getElementById("tabs").offsetHeight;
	if (navigator.appName.indexOf("Explorer") != -1) {
		var cwidth = document.documentElement.clientWidth;
		var cheight = document.documentElement.clientHeight;
		var ifrmwidth = cwidth;
		var ifrmheight = cheight - 24 - height_tabs;
	} else {
		var iwidth = window.innerWidth;
		var iheight = window.innerHeight;
		var ifrmwidth = iwidth;
		var ifrmheight = iheight - 24 - height_tabs;
	}
	var ifrmtop = 24 + height_tabs;
	var iframe;
	var framewidth;
	var frameheight;
	for (var i = 0; i < tabs.length; ++i) {
		iframe = document.getElementById('iframe_'+tabs[i]);
		iframe.style.width = ifrmwidth+"px";
		iframe.style.height = ifrmheight+"px";
		iframe.style.top = ifrmtop+"px";
	}
}
function restoreTabs() {
	var hash = window.location.hash.split(";");
	hash.shift();
	hash.pop();
	for (var i = 0; i < hash.length; ++i) {
		newTab("javascript:document.write(\""+hash[i]+"\");", hash[i]);
	}
}
